==> cuteradio_0.1.2.tar.gz: cuteradio-0.1.2/src/maemo5/stationlistwindow.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef SONGLISTWINDOW_H
#define SONGLISTWINDOW_H

#include "stackedwindow.h"

class StationFilterListModel;
class ListView;
class FilterBox;
class QLabel;
class QModelIndex;
class QVBoxLayout;

class StationListWindow : public StackedWindow
{
    Q_OBJECT

public:
    explicit StationListWindow(QWidget *parent = 0);

public slots:
    void searchStations(const QString &query);
    void showRecentlyPlayedStations();
    void showFavouriteStations();
    void showStationsByGenre(const QString &genre);
    void showStationsByCountry(const QString &country);
    void showStationsByLanguage(const QString &language);

    void clear();
    void reload();

private:
    void showEvent(QShowEvent *event);
    void keyPressEvent(QKeyEvent *event);

private slots:
    void onScrollingStopped();
    void onLoadingChanged(bool loading);
    void onCountChanged(int count);
    void showContextMenu(const QPoint &pos);
    void showStationInfo();
    void showEditDialog();
    void toggleFavourite();
    void deleteStation();
    void onItemClicked(const QModelIndex &index);

private:
    ListView *m_view;
    StationFilterListModel *m_model;
    FilterBox *m_filterBox;

    QMenu *m_contextMenu;
    QAction *m_infoAction;
    QAction *m_favouriteAction;
    QAction *m_editAction;
    QAction *m_deleteAction;

    QLabel *m_noResultsLabel;

    QVBoxLayout *m_vbox;
};

#endif // SONGLISTWINDOW_H

==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/maemo5/stationlistwindow.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef STATIONLISTWINDOW_H
#define STATIONLISTWINDOW_H

#include "stackedwindow.h"

class StationFilterListModel;
class ListView;
class FilterBox;
class QLabel;
class QModelIndex;
class QVBoxLayout;

class StationListWindow : public StackedWindow
{
    Q_OBJECT

public:
    explicit StationListWindow(QWidget *parent = 0);

public slots:
    void searchStations(const QString &query);
    void showRecentlyPlayedStations();
    void showFavouriteStations();
    void showStationsByGenre(const QString &genre);
    void showStationsByCountry(const QString &country);
    void showStationsByLanguage(const QString &language);

    void clear();
    void reload();

private:
    void showEvent(QShowEvent *event);
    void keyPressEvent(QKeyEvent *event);

private slots:
    void onScrollingStopped();
    void onLoadingChanged(bool loading);
    void onCountChanged(int count);
    void showContextMenu(const QPoint &pos);
    void showStationInfo();
    void showEditDialog();
    void toggleFavourite();
    void deleteStation();
    void onItemClicked(const QModelIndex &index);

private:
    ListView *m_view;
    StationFilterListModel *m_model;
    FilterBox *m_filterBox;

    QMenu *m_contextMenu;
    QAction *m_infoAction;
    QAction *m_favouriteAction;
    QAction *m_editAction;
    QAction *m_deleteAction;

    QLabel *m_noResultsLabel;

    QVBoxLayout *m_vbox;
};

#endif // STATIONLISTWINDOW_H
